| Title: | A Discrete Colour Palette |
|---|---|
| Description: | A discrete colour palette. These colours make it easier to create relatively accessible and colour-blind safe visualisation. |
| Authors: | David Hodge [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-3868-7501>) |
| Maintainer: | David Hodge <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-06-03 10:43:56 UTC |
| Source: | https://github.com/davidhodge931/jumble |
grey colour
greygrey
An object of class character of length 1.
scales::show_col(jumble::grey)scales::show_col(jumble::grey)
A pretty discrete colour palette that is relatively accessible.
Note only the first 3 colours are safe for all forms of colourblindness, as well as greyscale.
An extra safe colour that works is jumble::grey i.e. jumble::jumble[c(1:4, 7)].
jumblejumble
A character vector.
scales::show_col(jumble::jumble)scales::show_col(jumble::jumble)
Orange colour
orangeorange
An object of class character of length 1.
scales::show_col(jumble::orange)scales::show_col(jumble::orange)
Pink colour
pinkpink
An object of class character of length 1.
scales::show_col(jumble::pink)scales::show_col(jumble::pink)
Red colour
redred
An object of class character of length 1.
scales::show_col(jumble::red)scales::show_col(jumble::red)
Slate colour
slateslate
An object of class character of length 1.
scales::show_col(jumble::slate)scales::show_col(jumble::slate)
Teal colour
tealteal
An object of class character of length 1.
scales::show_col(jumble::teal)scales::show_col(jumble::teal)