Title: A Discrete Colour Palette
Version: 0.1.1
Description: A discrete colour palette. These colours make it easier to create relatively accessible and colour-blind safe visualisation.
License: MIT + file LICENSE
URL: https://github.com/davidhodge931/jumble, https://davidhodge931.github.io/jumble/
BugReports: https://github.com/davidhodge931/jumble/issues
Depends: R (≥ 4.1.0)
Suggests: scales, spelling, testthat (≥ 3.0.0)
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-04 02:36:34 UTC; david
Author: David Hodge ORCID iD [aut, cre, cph]
Maintainer: David Hodge <davidhodge931@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-04 05:30:02 UTC

grey colour

Description

grey colour

Usage

grey

Format

An object of class character of length 1.

Examples

scales::show_col(jumble::grey)

A discrete colour palette

Description

A pretty discrete colour palette that is relatively accessible.

Note only the first 3 colours are safe for all forms of colourblindness, as well as greyscale.

An extra safe colour that works is jumble::grey i.e. jumble::jumble[c(1:4, 7)].

Usage

jumble

Value

A character vector.

Examples

scales::show_col(jumble::jumble)

Description

Navy colour

Usage

navy

Format

An object of class character of length 1.

Examples

scales::show_col(jumble::navy)

Orange colour

Description

Orange colour

Usage

orange

Format

An object of class character of length 1.

Examples

scales::show_col(jumble::orange)

Pink colour

Description

Pink colour

Usage

pink

Format

An object of class character of length 1.

Examples

scales::show_col(jumble::pink)

Red colour

Description

Red colour

Usage

red

Format

An object of class character of length 1.

Examples

scales::show_col(jumble::red)

Slate colour

Description

Slate colour

Usage

slate

Format

An object of class character of length 1.

Examples

scales::show_col(jumble::slate)

Teal colour

Description

Teal colour

Usage

teal

Format

An object of class character of length 1.

Examples

scales::show_col(jumble::teal)