The hardware and bandwidth for this mirror is donated by METANET, the Webhosting and Full Service-Cloud Provider.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]metanet.ch.

Title: A Discrete Colour Palette
Version: 0.1.0
Description: A pretty discrete colour palette that is also relatively colourblind and contrast-safe for a light background.
License: MIT + file LICENSE
URL: https://github.com/davidhodge931/jumble, https://davidhodge931.github.io/jumble/
BugReports: https://github.com/davidhodge931/jumble/issues
Depends: R (≥ 4.1.0)
Suggests: scales, testthat (≥ 3.0.0)
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-03-09 18:56:46 UTC; david
Author: David Hodge ORCID iD [aut, cre, cph]
Maintainer: David Hodge <davidhodge931@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-16 15:50:16 UTC

grey colour

Description

grey colour

Usage

grey

Format

An object of class character of length 1.

Examples

scales::show_col(grey)

A discrete colour palette

Description

A pretty discrete 5 colour palette that is relatively colourblind and contrast safe on a light background.

A pretty discrete colour palette that is also relatively colourblind and contrast safe on a light background.

Note:

A 5 colour alternative that is colour-blind safe for deutanomaly, protanomaly and tritanomaly is jumble[c(1:4, 7)].

Usage

jumble

Value

A character vector.

Examples

scales::show_col(jumble)

Description

Navy colour

Usage

navy

Format

An object of class character of length 1.

Examples

scales::show_col(navy)

Orange colour

Description

Orange colour

Usage

orange

Format

An object of class character of length 1.

Examples

scales::show_col(orange)

Pink colour

Description

Pink colour

Usage

pink

Format

An object of class character of length 1.

Examples

scales::show_col(pink)

Red colour

Description

Red colour

Usage

red

Format

An object of class character of length 1.

Examples

scales::show_col(red)

Slate colour

Description

Slate colour

Usage

slate

Format

An object of class character of length 1.

Examples

scales::show_col(slate)

Teal colour

Description

Teal colour

Usage

teal

Format

An object of class character of length 1.

Examples

scales::show_col(teal)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.